@@ -53,6 +53,7 @@ class SeleniumDriverCore(object):
             if api_key is None:
                 return driver
         self.api_key = api_key
+        self._driver_type = None
         self.last_test_case_screenshot_uuid = None
         self.run_id = str(uuid.uuid1())
         self.debug = initialization_options.get('debug', False)
@@ -70,7 +71,7 @@ class SeleniumDriverCore(object):
 
         test_case_name = initialization_options.get('test_case_name', None)
         if test_case_name is None:
-            test_case_name = traceback.format_stack()[0].split()[1].split('/')[-1].split('.py')[0]
+            test_case_name = traceback.format_stack()[0].split()[1].split('/')[-1].split('\\')[-1].split('.py')[0]
         self.test_case_uuid = test_case_name
         try:
             self.test_case_creation_mode = strtobool(os.environ.get('DEVTOOLSAI_INTERACTIVE', '0')) == 1
@@ -407,7 +408,7 @@ class SeleniumDriverCore(object):
                         # Key is None when element is frozen or another issue during screenshot and upload.
                         self._update_elem(driver_element, key, element_name)
                 except Exception as e:
-                    log.error('error uploading screenshot to devtools. Continuing.')
+                    log.error('error uploading screenshot to Dev Tools. Continuing.')
             return driver_element
         except NoElementFoundException as e:
             log.exception(e)
@@ -531,7 +532,7 @@ class SeleniumDriverCore(object):
         screenshot_uuid = self.get_screenshot_hash(screenshotBase64)
         self.ref_screenshot_uuid = None
         self.page_offset = 0
-        if driver_element is not None:
+        if driver_element is not None and self._driver_type == 'selenium':
             self.page_offset = self.driver.execute_script('return window.pageYOffset')
             needs_to_scroll = (driver_element.rect['y'] > (self.window_size['height'] + self.page_offset)) or (driver_element.rect['y'] < self.page_offset)
             if needs_to_scroll:
